==> gcomp_src_2.1.3.beta.zip: DlgForm_Tables.cpp <==

#include "DialogForm.h"
#include "DlgFormFlags.h"


CHotKey::VK_Pair CHotKey::virtual_keys[] = {
	{0x01, "LButton"},
	{0x02, "RButton"},
	{0x08, "BackSpase"},
	{0x09, "Tab"},
	//{0x10, "Shift"},
	//{0x11, "Ctrl"},
	//{0x12, "Alt"},
	{0x0d, "Enter"},
	{0x13, "Pause"},
	{0x14, "CapsLock"},
	{0x1b, "Esc"},
	{0x20, "Space"},
	{0x21, "PgUp"},
	{0x22, "PgDn"},
	{0x23, "End"},
	{0x24, "Home"},
	{0x25, "Left"},
	{0x26, "Up"},
	{0x27, "Right"},
	{0x28, "Down"},
	{0x2c, "PrintScreen"},
	{0x2d, "Ins"},
	{0x2e, "Del"},
	{0x5d, "Apps"},
	{0x60, "Gray0"},
	{0x61, "Gray1"},
	{0x62, "Gray2"},
	{0x63, "Gray3"},
	{0x64, "Gray4"},
	{0x65, "Gray5"},
	{0x66, "Gray6"},
	{0x67, "Gray7"},
	{0x68, "Gray8"},
	{0x69, "Gray9"},
	{0x6a, "Gray*"},
	{0x6b, "Gray+"},
	{0x6c, "Separator"},
	{0x6d, "Gray-"},
	{0x6e, "GrayDecimal"},
	{0x6f, "Gray/"},
	{0x70, "F1"},
	{0x71, "F2"},
	{0x72, "F3"},
	{0x73, "F4"},
	{0x74, "F5"},
	{0x75, "F6"},
	{0x76, "F7"},
	{0x77, "F8"},
	{0x78, "F9"},
	{0x79, "F10"},
	{0x7a, "F11"},
	{0x7b, "F12"},
	{0x90, "NumLock"},
	{0x91, "ScrollLock"},
	{0xa0, "LShift"},
	{0xa1, "RShift"},
	{0xa2, "LControl"},
	{0xa3, "RControl"},
	{0x90, "NumLock"},
	{0, ""}
};

CObjectProperty CFormFont::Props[] = {
	{"",  0,  CObjectProperty::t_double,    NULL, sizeof(double), 0},
	{"Param2",  1,  CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param3",  2,  CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param4",  3,  CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",  4,  CObjectProperty::t_bool,   NULL, sizeof(bool), 0},
	{"",  5,  CObjectProperty::t_bool,   NULL, sizeof(bool), 0},
	{"", 6, CObjectProperty::t_bool, NULL, sizeof(bool), 0},
	{"Param8",  7,  CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param9",  8,  CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param10", 9,  CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param11", 10, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param12", 11, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param13", 12, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",   13, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{NULL, 0, CObjectProperty::t_int, 0, 0}
};
CPropertySet CFormFont::PropSet(Props, new CFormFont);


char* CFormControlBase::FlagList[] = {
	"Flag0",				//0
	"Flag1",				//1
	"Flag2",				//2
	"",		//3
	"Flag4",				//4
	"",	//5 (CHECKBOX - ; 1CEDIT -   )
	"",	//6
	"Flag7",				//7
	"Flag8",				//8
	"Flag9",				//9
	"Flag10",				//10
	"Flag11",				//11
	"",	//12
	"Flag13",				//13
	"Flag14",				//14
	"Flag15",				//15
	"Flag16",				//16
	"",		//17
	"Flag18",				//18
	"Flag19",				//19
	"Flag20",				//20
	"Flag21",				//21
	"Flag22",				//22
	"Flag23",				//23
	"Flag24",				//24
	"Flag25",				//25
	"Flag26",				//26
	"Flag27",				//27
	"Flag28",				//28
	"Flag29",				//29
	"Flag30",				//30
	"Flag31"				//31
};

char* CFormControlBase::BasicFlagList[] = {
	"Flag0",						//0
	"Flag1",						//1
	"",			//2
	"Flag3",						//3
	"",			//4
	"",						//5
	"",				//6
	"",				//7
	"",			//8
	"",				//9
	"",				//10
	"",		//11
	"",				//12
	"",						//13
	"",					//14
	"Flag15",						//15
	"",				//16
	"",					//17
	"",				//18
	"",				//19
	"",					//20
	"Flag21",						//21
	"",					//22
	"",				//23
	"",					//24
	"",					//25
	"",			//26
	"",		//27
	"",		//28
	"Flag29",						//29
	"Flag30",						//30
	"Flag31"						//31
};

char* CFormControlBase::ValueFlagList[] = {
	"",
	"",
	"Bit2", //    
	"Bit3",
	"Bit4",
	"Bit5",
	"Bit6",
	"Bit7"
};


CObjectProperty CFormControl::Props[] = {
	{"",      0, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"",          1, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"", 12, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"", 13, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",           14, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",         15, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",      16, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"", 17, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"", 18, CObjectProperty::t_bitset, ValueFlagList, sizeof(unsigned int), 0},
	{"",       2, CObjectProperty::t_bitset, FlagList, sizeof(unsigned int), 0},
	{"X",              3, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Y",              4, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",         5, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",         6, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",        7, CObjectProperty::t_bool,   NULL, sizeof(bool), 0},
	{"Param9",         8, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",  9,  CObjectProperty::t_int, NULL, sizeof(int), 0},
	{"Param11",       10, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",       11, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"",      19, CObjectProperty::t_bitset, BasicFlagList, sizeof(unsigned int), 0},
	{"",         20, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"Hint",          21, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"ShortHint",     22, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"Param24",       23, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",         24, CObjectProperty::t_object, NULL, sizeof(CFormFont), 0},
	{"",    38, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param40",       39, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",   40, CObjectProperty::t_uint,   NULL, sizeof(unsigned int), 0},
	{"",          41, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"HotKey",        42, CObjectProperty::t_object, NULL, sizeof(CHotKey), 0},
	{NULL, 0, CObjectProperty::t_int, 0, 0}
};
CPropertySet CFormControl::PropSet(Props, new CFormControl);


CObjectProperty CFormColumn::Props[] = {
	{"",       1, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"",           3, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",   7, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"", 8,  CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",             9, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",          10, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",       11, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",  12, CObjectProperty::t_string,    NULL, sizeof(CString), 0},
	{"",  13, CObjectProperty::t_bitset, ValueFlagList, sizeof(unsigned int), 0},
	{"",      0, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",          2, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",   4, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param6",          5, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",         6, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"Param15",        14, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"Param16",        15, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",   16, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",       17, CObjectProperty::t_bitset, BasicFlagList, sizeof(unsigned int), 0},
	{"",          18, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"Hint",           19, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"ShortHint",      20, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"Param22",        21, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{NULL, 0, CObjectProperty::t_int, 0, 0}
};
CPropertySet CFormColumn::PropSet(Props, new CFormColumn);


char* CDialogForm::FlagList[] = {
	"FormFlag0",				//0
	"FormFlag1",				//1
	"FormFlag2",				//2
	"FormFlag3",				//3
	"FormFlag4",				//4
	"FormFlag5",				//5
	"FormFlag6",				//6
	"FormFlag7",				//7
	"",		//8
	"FormFlag9",				//9
	"",			//10
	"",	//11
	"FormFlag12",				//12
	"FormFlag13",				//13
	"FormFlag14",				//14
	"FormFlag15",				//15
	"FormFlag16",				//16
	"FormFlag17",				//17
	"FormFlag18",				//18
	"FormFlag19",				//19
	"",		//20
	"FormFlag21",				//21
	"FormFlag22",				//22
	"FormFlag23",				//23
	"FormFlag24",				//24
	"FormFlag25",				//25
	"FormFlag26",				//26
	"FormFlag27",				//27
	"FormFlag28",				//28
	"FormFlag29",				//29
	"FormFlag30",				//30
	"FormFlag31"				//31
};

CObjectProperty CDialogForm::Props[] = {
	{"",               0, CObjectProperty::t_object, NULL, sizeof(CFormFont), 0},
	{"",              14, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",              15, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",           16, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"Param18",             17, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"Param19",             18, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",               19, CObjectProperty::t_bitset, FlagList, sizeof(unsigned int), 0},
	{"Param21",             20, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",    21, CObjectProperty::t_bool,   NULL, sizeof(bool), 0},
	{"",   22, CObjectProperty::t_bool,   NULL, sizeof(bool), 0},
	{"Param24",             23, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"Param25",             24, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",            25, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param27",             26, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"2",              27, CObjectProperty::t_bitset, FlagList, sizeof(unsigned int), 0},
	{"",                28, CObjectProperty::t_object, NULL, sizeof(CFormLayers), 0},
	{"",  29, CObjectProperty::t_bool,   NULL, sizeof(bool), 0},
	{"",      30, CObjectProperty::t_bool,   NULL, sizeof(bool), 0},
	{NULL, 0, CObjectProperty::t_int, 0, 0}
};
CPropertySet CDialogForm::PropSet(Props, new CDialogForm);

==> gcomp_src_2.1.6.beta.zip: DlgForm_Tables.cpp <==

#include "DialogForm.h"
#include "DlgFormFlags.h"


CHotKey::VK_Pair CHotKey::virtual_keys[] = {
	{0x01, "LButton"},
	{0x02, "RButton"},
	{0x08, "BackSpase"},
	{0x09, "Tab"},
	//{0x10, "Shift"},
	//{0x11, "Ctrl"},
	//{0x12, "Alt"},
	{0x0d, "Enter"},
	{0x13, "Pause"},
	{0x14, "CapsLock"},
	{0x1b, "Esc"},
	{0x20, "Space"},
	{0x21, "PgUp"},
	{0x22, "PgDn"},
	{0x23, "End"},
	{0x24, "Home"},
	{0x25, "Left"},
	{0x26, "Up"},
	{0x27, "Right"},
	{0x28, "Down"},
	{0x2c, "PrintScreen"},
	{0x2d, "Ins"},
	{0x2e, "Del"},
	{0x5d, "Apps"},
	{0x60, "Gray0"},
	{0x61, "Gray1"},
	{0x62, "Gray2"},
	{0x63, "Gray3"},
	{0x64, "Gray4"},
	{0x65, "Gray5"},
	{0x66, "Gray6"},
	{0x67, "Gray7"},
	{0x68, "Gray8"},
	{0x69, "Gray9"},
	{0x6a, "Gray*"},
	{0x6b, "Gray+"},
	{0x6c, "Separator"},
	{0x6d, "Gray-"},
	{0x6e, "GrayDecimal"},
	{0x6f, "Gray/"},
	{0x70, "F1"},
	{0x71, "F2"},
	{0x72, "F3"},
	{0x73, "F4"},
	{0x74, "F5"},
	{0x75, "F6"},
	{0x76, "F7"},
	{0x77, "F8"},
	{0x78, "F9"},
	{0x79, "F10"},
	{0x7a, "F11"},
	{0x7b, "F12"},
	{0x90, "NumLock"},
	{0x91, "ScrollLock"},
	{0xa0, "LShift"},
	{0xa1, "RShift"},
	{0xa2, "LControl"},
	{0xa3, "RControl"},
	{0x90, "NumLock"},
	{0, ""}
};

CObjectProperty CFormFont::Props[] = {
	{"",  0,  CObjectProperty::t_double,    NULL, sizeof(double), 0},
	{"Param2",  1,  CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param3",  2,  CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param4",  3,  CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",  4,  CObjectProperty::t_bool,   NULL, sizeof(bool), 0},
	{"",  5,  CObjectProperty::t_bool,   NULL, sizeof(bool), 0},
	{"", 6, CObjectProperty::t_bool, NULL, sizeof(bool), 0},
	{"Param8",  7,  CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param9",  8,  CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param10", 9,  CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param11", 10, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param12", 11, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param13", 12, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",   13, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{NULL, 0, CObjectProperty::t_int, 0, 0}
};
CPropertySet CFormFont::PropSet(Props, new CFormFont);


char* CFormControlBase::FlagList[] = {
	"Flag0",				//0
	"Flag1",				//1
	"Flag2",				//2
	"",		//3
	"Flag4",				//4
	"",	//5 (CHECKBOX - ; 1CEDIT -   )
	"",	//6
	"Flag7",				//7
	"Flag8",				//8
	"Flag9",				//9
	"Flag10",				//10
	"Flag11",				//11
	"",	//12
	"Flag13",				//13
	"Flag14",				//14
	"Flag15",				//15
	"Flag16",				//16
	"",		//17
	"Flag18",				//18
	"Flag19",				//19
	"Flag20",				//20
	"Flag21",				//21
	"Flag22",				//22
	"Flag23",				//23
	"Flag24",				//24
	"Flag25",				//25
	"Flag26",				//26
	"Flag27",				//27
	"Flag28",				//28
	"Flag29",				//29
	"Flag30",				//30
	"Flag31"				//31
};

char* CFormControlBase::BasicFlagList[] = {
	"Flag0",						//0
	"Flag1",						//1
	"",			//2
	"Flag3",						//3
	"",			//4
	"",						//5 //   .  .   .
	"",				//6
	"",				//7
	"",			//8
	"",				//9
	"",				//10
	"",		//11
	"",				//12
	"",						//13
	"",					//14
	"Flag15",						//15
	"",				//16
	"",					//17
	"",				//18
	"",				//19
	"",					//20
	"Flag21",						//21
	"",					//22
	"",				//23
	"",					//24
	"",					//25
	"",			//26
	"",		//27
	"",		//28
	"Flag29",						//29
	"Flag30",						//30
	"Flag31"						//31
};

char* CFormControlBase::ValueFlagList[] = {
	"",
	"",
	"Bit2", //    
	"Bit3",
	"Bit4",
	"Bit5",
	"Bit6",
	"Bit7"
};


CObjectProperty CFormControl::Props[] = {
	{"",      0, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"",          1, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"", 12, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"", 13, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",           14, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",         15, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",      16, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"", 17, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"", 18, CObjectProperty::t_bitset, ValueFlagList, sizeof(unsigned int), 0},
	{"",       2, CObjectProperty::t_bitset, FlagList, sizeof(unsigned int), 0},
	{"X",              3, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Y",              4, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",         5, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",         6, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",        7, CObjectProperty::t_bool,   NULL, sizeof(bool), 0},
	{"Param9",         8, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",  9,  CObjectProperty::t_int, NULL, sizeof(int), 0},
	{"Param11",       10, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",       11, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"",      19, CObjectProperty::t_bitset, BasicFlagList, sizeof(unsigned int), 0},
	{"",         20, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"Hint",          21, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"ShortHint",     22, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"Param24",       23, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",         24, CObjectProperty::t_object, NULL, sizeof(CFormFont), 0},
	{"",    38, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param40",       39, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",   40, CObjectProperty::t_uint,   NULL, sizeof(unsigned int), 0},
	{"",          41, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"HotKey",        42, CObjectProperty::t_object, NULL, sizeof(CHotKey), 0},
	{NULL, 0, CObjectProperty::t_int, 0, 0}
};
CPropertySet CFormControl::PropSet(Props, new CFormControl);


CObjectProperty CFormColumn::Props[] = {
	{"",       1, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"",           3, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",   7, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"", 8,  CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",             9, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",          10, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",       11, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",  12, CObjectProperty::t_string,    NULL, sizeof(CString), 0},
	{"",  13, CObjectProperty::t_bitset, ValueFlagList, sizeof(unsigned int), 0},
	{"",      0, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",          2, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",   4, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"Param6",          5, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",         6, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"Param15",        14, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"Param16",        15, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",   16, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",       17, CObjectProperty::t_bitset, BasicFlagList, sizeof(unsigned int), 0},
	{"",          18, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"Hint",           19, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"ShortHint",      20, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"Param22",        21, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{NULL, 0, CObjectProperty::t_int, 0, 0}
};
CPropertySet CFormColumn::PropSet(Props, new CFormColumn);


char* CDialogForm::FlagList[] = {
	"FormFlag0",				//0
	"FormFlag1",				//1
	"FormFlag2",				//2
	"FormFlag3",				//3
	"FormFlag4",				//4
	"FormFlag5",				//5
	"FormFlag6",				//6
	"",					//7
	"",		//8
	"FormFlag9",				//9
	"",			//10
	"",	//11
	"FormFlag12",				//12
	"FormFlag13",				//13
	"FormFlag14",				//14
	"FormFlag15",				//15
	"FormFlag16",				//16
	"FormFlag17",				//17
	"FormFlag18",				//18
	"FormFlag19",				//19
	"",		//20
	"FormFlag21",				//21
	"FormFlag22",				//22
	"FormFlag23",				//23
	"FormFlag24",				//24
	"FormFlag25",				//25
	"FormFlag26",				//26
	"FormFlag27",				//27
	"FormFlag28",				//28
	"FormFlag29",				//29
	"FormFlag30",				//30
	"FormFlag31"				//31
};

CObjectProperty CDialogForm::Props[] = {
	{"",               0, CObjectProperty::t_object, NULL, sizeof(CFormFont), 0},
	{"",              14, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",              15, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"",           16, CObjectProperty::t_quotstring, NULL, sizeof(CString), 0},
	{"Param18",             17, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"Param19",             18, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",               19, CObjectProperty::t_bitset, FlagList, sizeof(unsigned int), 0},
	{"Param21",             20, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",    21, CObjectProperty::t_bool,   NULL, sizeof(bool), 0},
	{"",   22, CObjectProperty::t_bool,   NULL, sizeof(bool), 0},
	{"Param24",             23, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"Param25",             24, CObjectProperty::t_string, NULL, sizeof(CString), 0},
	{"",            25, CObjectProperty::t_int,    NULL, sizeof(int), 0},
	{"", 26, CObjectProperty::t_uint, NULL, sizeof(unsigned int), 0},
	{"2",              27, CObjectProperty::t_bitset, FlagList, sizeof(unsigned int), 0},
	{"",                28, CObjectProperty::t_object, NULL, sizeof(CFormLayers), 0},
	{"",  29, CObjectProperty::t_bool,   NULL, sizeof(bool), 0},
	{"",      30, CObjectProperty::t_bool,   NULL, sizeof(bool), 0},
	{NULL, 0, CObjectProperty::t_int, 0, 0}
};
CPropertySet CDialogForm::PropSet(Props, new CDialogForm);
